package com.yiqi.order.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.order.domain.OrderPurchaseGoodsSku;

/**
 * 商品订单物料明细Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-20
 */
@Mapper
public interface OrderPurchaseGoodsSkuMapper extends BaseMapper<OrderPurchaseGoodsSku> {
    /**
     * 查询商品订单物料明细
     *
     * @param id 商品订单物料明细主键
     * @return 商品订单物料明细
     */
    public OrderPurchaseGoodsSku selectOrderPurchaseGoodsSkuById(Long id);

    /**
     * 查询商品订单物料明细列表
     *
     * @param orderPurchaseGoodsSku 商品订单物料明细
     * @return 商品订单物料明细集合
     */
    public List<OrderPurchaseGoodsSku> selectOrderPurchaseGoodsSkuList(OrderPurchaseGoodsSku orderPurchaseGoodsSku);

    /**
     * 新增商品订单物料明细
     *
     * @param orderPurchaseGoodsSku 商品订单物料明细
     * @return 结果
     */
    public int insertOrderPurchaseGoodsSku(OrderPurchaseGoodsSku orderPurchaseGoodsSku);

    /**
     * 修改商品订单物料明细
     *
     * @param orderPurchaseGoodsSku 商品订单物料明细
     * @return 结果
     */
    public int updateOrderPurchaseGoodsSku(OrderPurchaseGoodsSku orderPurchaseGoodsSku);

    /**
     * 删除商品订单物料明细
     *
     * @param id 商品订单物料明细主键
     * @return 结果
     */
    public int deleteOrderPurchaseGoodsSkuById(Long id);

    /**
     * 批量删除商品订单物料明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderPurchaseGoodsSkuByIds(Long[] ids);
}
