package com.yiqi.admin.controller.order;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.order.domain.OrderPurchaseGoodsSku;
import com.yiqi.order.service.IOrderPurchaseGoodsSkuService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 商品订单物料明细Controller
 *
 * @author ruoyi
 * @date 2023-10-20
 */
@Api(tags = "管理后台 - 进出货商品订单物料明细")
@RestController
@RequestMapping(UrlConstants.managerApi + "/order/purchaseGoodsSku")
public class OrderPurchaseGoodsSkuController extends BaseController {
    @Autowired
    private IOrderPurchaseGoodsSkuService orderPurchaseGoodsSkuService;

    /**
     * 查询商品订单物料明细列表
     */
    @PreAuthorize("@ss.hasPermi('order:purchaseGoodsSku:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询商品订单物料明细列表")
    public TableDataInfo list(OrderPurchaseGoodsSku orderPurchaseGoodsSku) {
        startPage();
        List<OrderPurchaseGoodsSku> list = orderPurchaseGoodsSkuService.selectOrderPurchaseGoodsSkuList(orderPurchaseGoodsSku);
        return getDataTable(list);
    }

    /**
     * 导出商品订单物料明细列表
     */
    @PreAuthorize("@ss.hasPermi('order:purchaseGoodsSku:export')")
    @Log(title = "商品订单物料明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出商品订单物料明细列表")
    public void export(HttpServletResponse response, OrderPurchaseGoodsSku orderPurchaseGoodsSku) {
        List<OrderPurchaseGoodsSku> list = orderPurchaseGoodsSkuService.selectOrderPurchaseGoodsSkuList(orderPurchaseGoodsSku);
        ExcelUtil<OrderPurchaseGoodsSku> util = new ExcelUtil<OrderPurchaseGoodsSku>(OrderPurchaseGoodsSku. class);
        util.exportExcel(response, list, "商品订单物料明细数据");
    }

    /**
     * 获取商品订单物料明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('order:purchaseGoodsSku:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取商品订单物料明细详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(orderPurchaseGoodsSkuService.selectOrderPurchaseGoodsSkuById(id));
    }

    /**
     * 新增商品订单物料明细
     */
    @PreAuthorize("@ss.hasPermi('order:purchaseGoodsSku:add')")
    @Log(title = "商品订单物料明细", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增商品订单物料明细")
    public AjaxResult add(@RequestBody OrderPurchaseGoodsSku orderPurchaseGoodsSku) {
        orderPurchaseGoodsSku.setCreateById(getUserId());
        orderPurchaseGoodsSku.setCreateBy(getUsername());
        return toAjax(orderPurchaseGoodsSkuService.insertOrderPurchaseGoodsSku(orderPurchaseGoodsSku));
    }

    /**
     * 修改商品订单物料明细
     */
    @PreAuthorize("@ss.hasPermi('order:purchaseGoodsSku:edit')")
    @Log(title = "商品订单物料明细", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改商品订单物料明细")
    public AjaxResult edit(@RequestBody OrderPurchaseGoodsSku orderPurchaseGoodsSku) {
        orderPurchaseGoodsSku.setUpdateById(getUserId());
        orderPurchaseGoodsSku.setUpdateBy(getUsername());
        return toAjax(orderPurchaseGoodsSkuService.updateOrderPurchaseGoodsSku(orderPurchaseGoodsSku));
    }

    /**
     * 删除商品订单物料明细
     */
    @PreAuthorize("@ss.hasPermi('order:purchaseGoodsSku:remove')")
    @Log(title = "商品订单物料明细", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除商品订单物料明细")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(orderPurchaseGoodsSkuService.deleteOrderPurchaseGoodsSkuByIds(ids));
    }

}
